Index: trunk/psLib/src/sysUtils/psMemory.h
===================================================================
--- trunk/psLib/src/sysUtils/psMemory.h	(revision 4330)
+++ trunk/psLib/src/sysUtils/psMemory.h	(revision 4392)
@@ -12,6 +12,6 @@
  *  @ingroup MemoryManagement
  *
- *  @version $Revision: 1.41 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2005-06-21 03:01:37 $
+ *  @version $Revision: 1.42 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2005-06-25 02:02:05 $
  *
  *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -55,5 +55,5 @@
 
 /// typedef for deallocator.
-typedef void (*psFreeFcn) (psPtr ptr);
+typedef void (*psFreeFunc) (psPtr ptr);
 
 /** Book-keeping data for storage allocator.
@@ -67,5 +67,5 @@
     struct psMemBlock* previousBlock;  ///< previous block in allocation list
     struct psMemBlock* nextBlock;      ///< next block allocation list
-    psFreeFcn freeFcn;                 ///< deallocator.  If NULL, use generic deallocation.
+    psFreeFunc freeFcn;                 ///< deallocator.  If NULL, use generic deallocation.
     size_t userMemorySize;             ///< the size of the user-portion of the memory block
     const psMemoryId id;               ///< a unique ID for this allocation
@@ -152,5 +152,5 @@
 void psMemSetDeallocator(
     psPtr ptr,                         ///< the memory block to operate on
-    psFreeFcn freeFcn                  ///< the function to be executed at deallocation
+    psFreeFunc freeFcn                  ///< the function to be executed at deallocation
 );
 
@@ -162,7 +162,7 @@
  *  within a struct.
  *
- *  @return psFreeFcn    the routine to be called at deallocation.
- */
-psFreeFcn psMemGetDeallocator(
+ *  @return psFreeFunc    the routine to be called at deallocation.
+ */
+psFreeFunc psMemGetDeallocator(
     psPtr ptr                          ///< the memory block
 );
